@@ -1,20 +1,22 @@
 from .bamboo import Bamboo
 from .bitbucket import Bitbucket
 from .bitbucket import Bitbucket as Stash
+from .cloud_admin import CloudAdminOrgs, CloudAdminUsers
 from .confluence import Confluence
 from .crowd import Crowd
+from .insight import Insight
 from .jira import Jira
 from .marketplace import MarketPlace
 from .portfolio import Portfolio
 from .service_desk import ServiceDesk
 from .xray import Xray
-from .insight import Insight
-
 
 __all__ = [
     "Confluence",
     "Jira",
     "Bitbucket",
+    "CloudAdminOrgs",
+    "CloudAdminUsers",
     "Portfolio",
     "Bamboo",
     "Stash",
